TestClickBlankTarget

This test reproduces bug SEL-272

TestClickBlankTarget
open | ../tests/html/Frames.html |
selectFrame | bottomFrame |
click | changeBlank |
waitForPopUp | _blank | 10000
selectWindow | _blank |
click | changeSpan |
close |  |

And again, from the wrong frame

selectWindow | null |
click | changeBlank |
waitForPopUp | _blank | 10000
selectWindow | _blank |
click | changeSpan |
close |  |

Also try submitting a form with a _blank target

selectWindow | null |
selectFrame | bottomFrame |
submit | formBlank |
waitForPopUp | _blank | 10000
selectWindow | _blank |
click | changeSpan |
close |  |

window.open(url, _blank)

selectWindow | null |
open | ../tests/html/test_select_window.html |
click | popupBlank |
waitForPopUp | _blank | 10000
selectWindow | _blank |
verifyTitle | Select Window Popup |
close |  |